Package: PrInCE
Title: Predicting Interactomes from Co-Elution
Version: 1.27.0
Authors@R: c(
  person("Michael", "Skinnider", email = "michael.skinnider@msl.ubc.ca",
         role = c("aut", "trl", "cre")),
  person("R. Greg", "Stacey", email = "richard.greg.stacey@msl.ubc.ca",
         role = "ctb"),
  person("Nichollas", "Scott", email = "nichollas.scott@unimelb.edu.au",
         role = "ctb"),
  person("Anders", "Kristensen", role = "ctb"),
  person("Leonard", "Foster", email = "foster@msl.ubc.ca",
         role = c("aut", "led")))
BugReports: https://github.com/fosterlab/PrInCE/issues
Description: PrInCE (Predicting Interactomes from Co-Elution) uses a naive
  Bayes classifier trained on dataset-derived features to recover
  protein-protein interactions from co-elution chromatogram profiles. This
  package contains the R implementation of PrInCE.
Depends: R (>= 3.6.0)
Imports: purrr (>= 0.2.4), dplyr (>= 0.7.4), tidyr (>= 0.8.99),
        forecast (>= 8.2), progress (>= 1.1.2), Hmisc (>= 4.0),
        naivebayes (>= 0.9.1), robustbase (>= 0.92-7), ranger (>=
        0.8.0), LiblineaR (>= 2.10-8), speedglm (>= 0.3-2), tester (>=
        0.1.7), magrittr (>= 1.5), Biobase (>= 2.40.0), MSnbase (>=
        2.8.3), stats, utils, methods, Rdpack (>= 0.7)
Suggests: BiocStyle, knitr, rmarkdown
biocViews: Proteomics, SystemsBiology, NetworkInference
VignetteBuilder: knitr
License: GPL-3 + file LICENSE
Encoding: UTF-8
RdMacros: Rdpack
RoxygenNote: 7.1.1
git_url: https://git.bioconductor.org/packages/PrInCE
git_branch: devel
git_last_commit: bfd792d
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-31
NeedsCompilation: no
Packaged: 2025-10-31 23:33:32 UTC; biocbuild
Author: Michael Skinnider [aut, trl, cre],
  R. Greg Stacey [ctb],
  Nichollas Scott [ctb],
  Anders Kristensen [ctb],
  Leonard Foster [aut, led]
Maintainer: Michael Skinnider <michael.skinnider@msl.ubc.ca>
