# Generated by roxygen2: do not edit by hand

export(PrInCE)
export(adjacency_matrix_from_data_frame)
export(adjacency_matrix_from_list)
export(build_gaussians)
export(calculate_autocorrelation)
export(calculate_features)
export(calculate_precision)
export(check_gaussians)
export(choose_gaussians)
export(clean_profile)
export(clean_profiles)
export(co_apex)
export(concatenate_features)
export(detect_complexes)
export(filter_profiles)
export(fit_curve)
export(fit_gaussians)
export(impute_neighbors)
export(is_unweighted)
export(is_weighted)
export(make_feature_from_data_frame)
export(make_feature_from_expression)
export(make_initial_conditions)
export(make_labels)
export(match_matrix_dimensions)
export(predict_ensemble)
export(predict_interactions)
export(replace_missing_data)
export(threshold_precision)
importFrom(Biobase,"exprs<-")
importFrom(Hmisc,rcorr)
importFrom(LiblineaR,LiblineaR)
importFrom(MSnbase,exprs)
importFrom(Rdpack,reprompt)
importFrom(dplyr,arrange)
importFrom(dplyr,filter)
importFrom(dplyr,first)
importFrom(dplyr,full_join)
importFrom(dplyr,group_by)
importFrom(dplyr,last)
importFrom(dplyr,mutate)
importFrom(dplyr,mutate_if)
importFrom(dplyr,n_distinct)
importFrom(dplyr,nth)
importFrom(dplyr,select)
importFrom(dplyr,starts_with)
importFrom(dplyr,ungroup)
importFrom(forecast,ma)
importFrom(magrittr,"%>%")
importFrom(methods,is)
importFrom(naivebayes,naive_bayes)
importFrom(progress,progress_bar)
importFrom(purrr,map)
importFrom(purrr,map_dbl)
importFrom(purrr,map_dfr)
importFrom(purrr,map_int)
importFrom(purrr,map_lgl)
importFrom(ranger,ranger)
importFrom(robustbase,rowMedians)
importFrom(speedglm,speedglm)
importFrom(stats,binomial)
importFrom(stats,coef)
importFrom(stats,cor)
importFrom(stats,dist)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,nls)
importFrom(stats,predict)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(tester,is_logical_matrix)
importFrom(tester,is_numeric_matrix)
importFrom(tester,is_square_matrix)
importFrom(tidyr,crossing)
importFrom(utils,combn)
