General Information
===================

LibThai is a set of Thai language support routines aimed to ease
developers' tasks to incorporate Thai language support in their
applications. It includes important Thai-specific functions e.g. word
breaking, input and output methods as well as basic character and
string supports. LibThai is an Open Source and collaborative effort
initiated by Thai Linux Working Group and opened for all contributors.

LibThai includes Thai language support routines:

  - Thai character set support: TIS 620, ISO/IEC 10646
  - Thai character properties
  - Thai string manipulators
  - Thai string collation
  - Thai word breaking
  - Thai cell clustering
  - Thai input method
  - Thai output method

More information about LibThai can be found at its official web site:
https://linux.thai.net/projects/libthai/ or via e-mail
thai-linux-foss-devel@googlegroups.com

Installation
============

See the file 'INSTALL'.

License
=======

LibThai is copyrighted by its authors and licensed under terms of the
GNU Lesser Public License (LGPL) - see file COPYING for details.
